@@ -44,6 +44,7 @@ func RunOperator(ctx context.Context, controllerConfig *controllercmd.Controller
 	operator := NewOpenShiftControllerManagerOperator(
 		os.Getenv("IMAGE"),
 		operatorConfigInformers.Operator().V1().OpenShiftControllerManagers(),
+		configInformers.Config().V1().Proxies(),
 		kubeInformersForOpenshiftControllerManagerNamespace,
 		operatorClient.OperatorV1(),
 		kubeClient,
@@ -57,6 +58,7 @@ func RunOperator(ctx context.Context, controllerConfig *controllercmd.Controller
 
 	configObserver := configobservationcontroller.NewConfigObserver(
 		opClient,
+		operatorConfigInformers,
 		configInformers,
 		kubeInformersForOperatorNamespace,
 		controllerConfig.EventRecorder,
@@ -105,7 +107,7 @@ func (v *versionGetter) SetVersion(operandName, version string) {
 }
 
 func (v *versionGetter) GetVersions() map[string]string {
-	co, err := v.openshiftControllerManagers.Get("cluster", metav1.GetOptions{})
+	co, err := v.openshiftControllerManagers.Get(context.TODO(), "cluster", metav1.GetOptions{})
 	if co == nil || err != nil {
 		return map[string]string{}
 	}
